@@ -1,20 +1,22 @@
 #!/usr/bin/python2.5
 
+# Copyright (c) 2010 Christos Zamantzas
+# Licenced under GPLv2
+
 #################################################################
 ##   swappolube  -  Configuration UI for the swappolube script ##
 #################################################################
 
 ##Author: Christos Zamantzas <christos.zamantzas@gmail.com>
-##Version: 0.3-1
+Version = '0.3-2'
 
 import os
 import sys
 import time
 
-from PyQt4 import QtGui,QtCore
-from PyQt4.QtCore import SIGNAL, Qt
 from PyQt4.QtGui import *
-
+from PyQt4.QtCore import *
+from PyQt4.QtMaemo5 import *
 from swappolubeUI import *
 
 ##############################################################
@@ -30,7 +32,7 @@ MainFile     = 'tuning'                       # tuning file
 ##############################################################
 
 def CheckFile(Path, File):
-    """ Check if a file exists. """
+    ''' Check if a file exists. '''
 
     try:
         f = open(Path + File, 'r')
@@ -43,31 +45,27 @@ def CheckFile(Path, File):
 ##############################################################
         
 def showMessage(message):
-    """
-    Method to display a message to the user that waits for a confirmation.
-    """
+    ''' Method to display a message to the user that waits for a confirmation. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
-               /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog \
+               /org/freedesktop/Notifications \
+               org.freedesktop.Notifications.SystemNoteDialog \
                string:"%s" uint32:0 string:"OK"' % message)          
 
 ##############################################################  
 
 def showQuickMessage(message):
-    """
-    Method to display a message to the user.
-    """
+    ''' Method to display a message to the user. '''
 
     os.system('dbus-send --type=method_call --dest=org.freedesktop.Notifications \
-               /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
+               /org/freedesktop/Notifications \
+               org.freedesktop.Notifications.SystemNoteInfoprint \
                string:"%s"' % message)          
 
 ##############################################################  
 
 def doUpdateConfig():
-    """
-    Update the config file with the edited.
-    """
+    ''' Update the config file with the edited. '''
 
     time.sleep(1)
     try:
@@ -77,8 +75,92 @@ def doUpdateConfig():
     else: 
        return True
        
-# ##############################################################
+##############################################################
 
+class SwappolubeAbout(QMainWindow):
+    '''About Window'''
+    def __init__(self, parent=None):
+        QMainWindow.__init__(self,parent)
+        self.parent = parent
+        self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
+        self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
+        self.setWindowTitle("Swappolube About")
+
+        aboutScrollArea = QScrollArea(self)
+        aboutScrollArea.setWidgetResizable(True)
+        awidget = QWidget(aboutScrollArea)
+        awidget.setMinimumSize(480,1000)
+        awidget.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+        aboutScrollArea.setSizePolicy( QSizePolicy.Expanding, QSizePolicy.Expanding )
+        #Kinetic scroller is available on Maemo and should be on meego
+        try:
+            scroller = aboutScrollArea.property("kineticScroller").toPyObject()
+            scroller.setEnabled(True)
+        except:
+            pass
+
+        aboutLayout = QVBoxLayout(awidget)
+
+        aboutIcon = QLabel()
+        aboutIcon.setPixmap( QIcon.fromTheme('swappolube').pixmap(48,48) )
+        aboutIcon.setAlignment( Qt.AlignCenter or Qt.AlignHCenter )
+        aboutIcon.resize(128,128)
+        aboutLayout.addWidget(aboutIcon)
+
+        aboutLabel = QLabel('''<center><b>Swappolube</b> %s
+                                   <br>
+                                   <br>
+                                   <b>The SWAPPOLUBE application is 
+                                   <br>a user interface to the configuration 
+                                   <br>of several parameters of the N900 kernel 
+                                   <br>with the aim to make it faster.</b>
+                                   <br>
+                                   <br>Licenced under GPLv2
+                                   <br>by <b>Christos Zamantzas</b> (Saturn)
+                                   <br>
+                                   <br>It provides the ability to change a number 
+                                   <br>of parameters while in operation and 
+                                   <br>if chosen can make them persistent  
+                                   <br>by adding a script to event.d for them 
+                                   <br>to be set after each boot.
+                                   <br>
+                                   <br>
+                                   <b>Additional information on the usage, 
+                                   <br>settings and implications can be found 
+                                   <br>in the wiki page</b>
+                                   <br>
+                                   <br>
+                                   <br><b>Thanks to :</b>
+                                   <br><b>debernalis</b> at talk.maemo.org for
+                                   <br>the name, icon and the application idea.
+                                   <br>
+                                   <br><b>Benoit HERVIER</b> at http://khertan.net/
+                                   <br>for the code used in this about window.
+                                   <br>
+                                   </center>''' % Version)
+        aboutLayout.addWidget(aboutLabel)
+        self.bugtracker_button = QPushButton('BugTracker')
+        self.bugtracker_button.clicked.connect(self.open_bugtracker)
+        self.website_button = QPushButton('Wiki Page')
+        self.website_button.clicked.connect(self.open_website)
+        awidget2 = QWidget()
+        buttonLayout = QHBoxLayout(awidget2)        
+        buttonLayout.addWidget(self.bugtracker_button)
+        buttonLayout.addWidget(self.website_button)
+        aboutLayout.addWidget(awidget2)
+        
+        awidget.setLayout(aboutLayout)
+        aboutScrollArea.setWidget(awidget)
+        self.setCentralWidget(aboutScrollArea)
+        self.show()        
+        
+    def open_website(self):
+        QDesktopServices.openUrl(QUrl('http://wiki.maemo.org/Swappolube'))
+    def open_bugtracker(self):
+        QDesktopServices.openUrl(QUrl('https://bugs.maemo.org'))
+
+##############################################################
+        
 class MyMainWindow(QtGui.QMainWindow):
         def __init__(self, parent=None):
         
@@ -97,34 +179,49 @@ class MyMainWindow(QtGui.QMainWindow):
                ##Connect Menu Buttons 
              QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
              QtCore.QObject.connect(self.ui.actionAbout, QtCore.SIGNAL('triggered()'), self.doAbout)
-             QtCore.QObject.connect(self.ui.actionCredits, QtCore.SIGNAL('triggered()'), self.doCredits)
-             QtCore.QObject.connect(self.ui.actionDelete_Tunings, QtCore.SIGNAL('triggered()'), self.doDeleteTunings)
+             QtCore.QObject.connect(self.ui.actionRestoreDefault, QtCore.SIGNAL('triggered()'), self.doRestoreDefault)
+             QtCore.QObject.connect(self.ui.actionDeleteTunings, QtCore.SIGNAL('triggered()'), self.doDeleteTunings)
              
-             ##Set default values in the GUI
+             ##Set current values in the GUI
              self.doSetCurrent()
 
         ##Create Methods
                 
         def doAbout(self):
-             msg = "The SWAPPOLUBE Editor is a user interface to the configuration of several parameters of the N900 kernel with the aim to make it faster.\n"
-             msg += "It provides the ability to change a number of parameters while in operation and if chosen will make them persistent by adding a script to event.d to set them after each boot.\n"
-             msg += "Additional information could be found in http://wiki.maemo.org/Swappolube"
-             QMessageBox.about(self, "About - SWAPPOLUBE editor", msg)
+          self.aboutWin = SwappolubeAbout(self)
 
-        def doCredits(self):
-             msg = unichr(int('00A9', 16)) + "2010, Christos Zamantzas (saturn)\n"
-             msg += unichr(int('00A9', 16)) + "2010, Ernesto de Bernardis (debernardis)\n\n"
-             msg += "Configuration Interface for several kernel parameters\n"
-             msg += "Distributed under GPL ver. 2"
-             QMessageBox.about(self, "Credits - SWAPPOLUBE Editor", msg)
- 
         def doDeleteTunings(self): ##FIXME: check if file was deleted!!
              os.system('sudo %supdateTuning deleteTuning' % AppPath)
              message = 'The tuning file has been removed from the boot sequence.\nOn next reboot, the system will start with its default configuration.'
              showMessage(message)
 
+        def doRestoreDefault(self):
+             ''' Apply the the default values.'''
+             
+             message = 'Please wait. Update in progress..'
+             showQuickMessage(message)
+             
+             ##Update the values.
+             os.system('sudo %supdateTuning KillAllocatingTask 0' % AppPath )
+             os.system('sudo %supdateTuning PageCluster 5' % AppPath )
+             os.system('sudo %supdateTuning LaptopMode 0' % AppPath )
+             os.system('sudo %supdateTuning DirtyExpireCentisecs 500' % AppPath )
+             os.system('sudo %supdateTuning TCPTimestamps 1' % AppPath )
+             os.system('sudo %supdateTuning DirtyWritebackCentisecs 500' % AppPath )
+             os.system('sudo %supdateTuning TCPNoMetricsSave 0' % AppPath )
+             os.system('sudo %supdateTuning DirtyRatio 40' % AppPath )
+             os.system('sudo %supdateTuning Swappiness 100' % AppPath )
+             os.system('sudo %supdateTuning DirtyBGDRatio 10' % AppPath )
+             os.system('sudo %supdateTuning VFSCachePressure 100' % AppPath )
+             
+             message = 'The default configuration has been applied to the system.'
+             showMessage(message)
+             
+             ##Set current values in the GUI
+             self.doSetCurrent()
+             
         def doSetCurrent(self): ##FIXME: separate reading and setting to two methods!!!
-             """Set current values in the GUI"""
+             '''Set current values in the GUI'''
              
              ##Set values for enable/disable   
              self.ui.radioKillAllocatingTask.setChecked(False)
@@ -179,7 +276,7 @@ class MyMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
 
         def doSetProposed(self): ##FIXME: outsourse proposed values to a file!!!
-             """ Set default values in the GUI """
+             ''' Set proposed values in the GUI'''
              
              ##Set values for enable/disable   
              self.ui.radioKillAllocatingTask.setChecked(True)
@@ -213,7 +310,7 @@ class MyMainWindow(QtGui.QMainWindow):
              showQuickMessage(message)
              
         def doApplyConfig(self):
-             """ Apply the configuration shown in the gui now! It will be lost on next reboot."""
+             ''' Apply the configuration shown in the gui now! It will be lost on next reboot.'''
              
              message = 'Please wait. Update in progress..'
              showQuickMessage(message)
@@ -368,7 +465,7 @@ if __name__ == "__main__":
           else:
              pass
        
-          # #Open Dialog Window
+          ##Open Dialog Window
           app = QtGui.QApplication(sys.argv)
           myapp = MyMainWindow()
           myapp.show()
